<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="aboutui.ui" line="14"/>
        <source>About GPSBabel</source>
        <translation>Über GPSBabel</translation>
    </message>
    <message>
        <location filename="aboutui.ui" line="74"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Copyright (C) 2009-2016 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Installation ID: $installationId$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Copyright (C) 2009-2014 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;LGPL Crystal Icons by Elvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;Installation ID: $installationId$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <location filename="advui.ui" line="14"/>
        <source>Global Options</source>
        <translation>Globale Optionen</translation>
    </message>
    <message>
        <location filename="advui.ui" line="23"/>
        <source>Synthesize short names</source>
        <translation>Kurznamen generieren</translation>
    </message>
    <message>
        <source>Force Selected GPS data types (nuketypes filter)</source>
        <translatorcomment>not sur if there could be a better translation, the gui does not run here</translatorcomment>
        <translation type="obsolete">angekreuzte GPS Datentypen erzwingen {nuketypes-Filter}</translation>
    </message>
    <message>
        <location filename="advui.ui" line="36"/>
        <source>Enable character set transformation</source>
        <translatorcomment>alt: &apos;Codepage-Transformation aktivieren&apos; - more &apos;techspeak&apos;-like, but will be understood better</translatorcomment>
        <translation>Zeichentabellen-Transformation aktivieren</translation>
    </message>
    <message>
        <location filename="advui.ui" line="43"/>
        <source>Preview in Google Maps</source>
        <translation>Vorschau in Google Maps</translation>
    </message>
    <message>
        <location filename="advui.ui" line="57"/>
        <source>None</source>
        <translation>keine</translation>
    </message>
    <message>
        <location filename="advui.ui" line="62"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="advui.ui" line="67"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="advui.ui" line="72"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="advui.ui" line="77"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="advui.ui" line="82"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="advui.ui" line="87"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="advui.ui" line="92"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="advui.ui" line="97"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="advui.ui" line="102"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="advui.ui" line="107"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="advui.ui" line="115"/>
        <source>Debugging Diagnostics</source>
        <translation>Fehlerdiagnose</translation>
    </message>
    <message>
        <location filename="advui.ui" line="139"/>
        <source>Set all format input/output options to default values</source>
        <translation>Vorgaben für Formatoptionen aktivieren</translation>
    </message>
    <message>
        <location filename="advui.ui" line="142"/>
        <source>Default Format Options</source>
        <translatorcomment>&apos;Format-Presets&apos; more techspeak-like, but will be understood better</translatorcomment>
        <translation>Format-Vorgaben</translation>
    </message>
    <message>
        <location filename="advui.ui" line="33"/>
        <source>Convert character set encoding between input and output</source>
        <translation>Zeichentabelle zwischen Ein- und Ausgabe konvertieren</translation>
    </message>
    <message>
        <location filename="advui.ui" line="52"/>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation>Fehlersuche:
grössere Zahl bedeutet detailliertere Diagnosebeschreibungen.</translation>
    </message>
    <message>
        <location filename="advui.ui" line="20"/>
        <source>Create smart shortened names. </source>
        <translatorcomment>shortened names == shortnames???, translation is no sentence, this makes sense</translatorcomment>
        <translation>schlaue Kurznamen generieren.</translation>
    </message>
</context>
<context>
    <name>Donate</name>
    <message>
        <location filename="donate.ui" line="32"/>
        <source>Support GPSBabel</source>
        <translation>GPSBabel unterstützen</translation>
    </message>
    <message>
        <location filename="donate.ui" line="47"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;https://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed).&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel ist freie Software, programmiert und supportet von Freiwilligen. Jede Menge Zeit ist nötig um die Software herzustellen und zu warten, und spezielle Programme, GPS Receiver etc. kosten auch Geld. Bitte &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;tragen Sie zu dem Projekt bei: Ihre Zeit oder eine Spende über PayPal (Kein Account benötigt) oder Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="donate.ui" line="61"/>
        <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Wenn Sie schon zu dem Projekt beigetragen haben oder Sie nicht helfen können, markieren Sie bitte die Checkbox unten um diese Meldung nicht wieder zu sehen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="donate.ui" line="71"/>
        <source>Never show this message again.</source>
        <translation>Diese Meldung nicht mehr anzeigen</translation>
    </message>
    <message>
        <location filename="donate.ui" line="93"/>
        <source>No, Thanks</source>
        <translation>Nein, danke</translation>
    </message>
    <message>
        <location filename="donate.ui" line="100"/>
        <source>Contribute</source>
        <translation>Beitragen</translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <location filename="optionsdlg.cc" line="73"/>
        <source>Select input file</source>
        <translation>Originaldatei wählen</translation>
    </message>
    <message>
        <location filename="optionsdlg.cc" line="77"/>
        <source>Select output file</source>
        <translation>Zieldatei wählen</translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <location filename="filterdlg.cc" line="41"/>
        <source>Tracks</source>
        <translatorcomment>keep techspeak!</translatorcomment>
        <translation>Tracks</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="44"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="47"/>
        <source>Routes &amp; Tracks</source>
        <translation>Routen &amp; Tracks</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="50"/>
        <source>Miscellaneous</source>
        <translation>Verschiedenes</translation>
    </message>
    <message>
        <location filename="filterdlg.cc" line="104"/>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translatorcomment>reset: zurücksetzen, set: setzen</translatorcomment>
        <translation>Sind Sie sicher, dass Sie alle Filteroptionen auf die Vorgaben zurücksetzen wollen?</translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <location filename="filterui.ui" line="14"/>
        <source>Data Filters</source>
        <translation>Konverter</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="17"/>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation>Konverter manipulieren die Daten zwischen Ein- und Ausgabedateien oder -geräten.</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="72"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="83"/>
        <source>Reset</source>
        <translatorcomment>translation depends heavily on context</translatorcomment>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <location filename="gmapdlg.cc" line="55"/>
        <source>meters</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="64"/>
        <source>feet</source>
        <translatorcomment>alt: Fuß</translatorcomment>
        <translation>Fuss</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="68"/>
        <source>miles</source>
        <translation>Meilen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="71"/>
        <source>Length: %1 %2
  %3 %4</source>
        <translation>Länge: %1 %2
%3 %4</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="81"/>
        <source>Lat: %1</source>
        <translation>Breite: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="82"/>
        <source>Lng: %1</source>
        <translation>Länge: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="84"/>
        <source>Desc: %1</source>
        <translation>Beschr.: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="86"/>
        <source>Cmt: %1</source>
        <translation>Kommentar: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="88"/>
        <source>Ele: %1</source>
        <translation>Alt.: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="118"/>
        <source>Start: %1</source>
        <translation>Start: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="120"/>
        <source>Stop: %1</source>
        <translation>Stop: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="123"/>
        <source>Points: %1</source>
        <translation>Punkte: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="150"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="165"/>
        <source>Tracks</source>
        <translation>Tracks</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="180"/>
        <source>Routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="521"/>
        <source>Show All Waypoints</source>
        <translation>alle Wegpunkte zeigen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="522"/>
        <source>Hide All Waypoints</source>
        <translation>alle Wegpunkte verbergen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="523"/>
        <location filename="gmapdlg.cc" line="531"/>
        <location filename="gmapdlg.cc" line="539"/>
        <source>Expand All</source>
        <translation>alles ausführlich</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="524"/>
        <location filename="gmapdlg.cc" line="532"/>
        <location filename="gmapdlg.cc" line="540"/>
        <source>Collapse All</source>
        <translation>alles kurz</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="529"/>
        <source>Show All Routes</source>
        <translation>alle Routen zeigen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="530"/>
        <source>Hide All Routes</source>
        <translation>alle Routen verbergen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="537"/>
        <source>Show All Tracks</source>
        <translation>alle Tracks zeigen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="538"/>
        <source>Hide All Tracks</source>
        <translation>alle Tracks verbergen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="545"/>
        <source>Show Only This Waypoint</source>
        <translation>nur diesen Wegpunkt zeigen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="551"/>
        <source>Show Only This Track</source>
        <translation>nur diesen Track zeigen</translation>
    </message>
    <message>
        <location filename="gmapdlg.cc" line="557"/>
        <source>Show Only This Route</source>
        <translation>nur diese Route zeigen</translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <location filename="gmapui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="47"/>
        <source>Copy to Clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="50"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Über</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="obsolete">Hilfe</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Datei</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="obsolete">Gerät</translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="obsolete">Format</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="obsolete">Optionen</translation>
    </message>
    <message>
        <source>Waypoints</source>
        <translation type="obsolete">Wegpunkte</translation>
    </message>
    <message>
        <source>Routes</source>
        <translation type="obsolete">Routen</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="obsolete">Ausgabe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>default</source>
        <translation type="obsolete">default</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="528"/>
        <source>Select one or more input files</source>
        <translation>eine oder mehrere Originaldateien markieren</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="555"/>
        <source>Output File Name</source>
        <translation>Zieldatei-Name</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="615"/>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Fehler beim Lesen der Formatbeschreibung.  Prüfen Sie, dass &apos;gpsbabel&apos; korrekt installiert ist und im aktuellen PATH steht

Das Programm muss abgebrochen werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="626"/>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Einige Datei- oder Geräteformate wurden beim Aufstart nicht gefunden.  Prüfen Sie, dass &apos;gpsbabel&apos; korrekt installiert ist und im aktuellen PATH steht

Das Prgramm muss abgebrochen werden.</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="648"/>
        <source>Input and output formats do not support %1</source>
        <translation>Keine Unterstützung für %1 im Ein- oder Ausgabeformat</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="651"/>
        <source>Input does not support %1; output format supports %2</source>
        <translation>Keine Unterstützung für %1 im Eingabeformat; Ausgabeformat unterstützt %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="654"/>
        <source>Input format supports %1; output format does not support %2</source>
        <translation>Eingabeformat  unterstützt %1. Keine Unterstützung für %2 im Ausgabeformat</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="657"/>
        <source>Both input and output formats support %1</source>
        <translation>Ein- und Ausgabeformat unterstützen %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="678"/>
        <source>waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="679"/>
        <source>tracks</source>
        <translation>tracks</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="680"/>
        <source>routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="770"/>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation>Es gibt keine Eingabeoptionen für das Format &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="777"/>
        <location filename="mainwindow.cc" line="797"/>
        <source>Options for %1</source>
        <translation>Optionen für %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="790"/>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation>Es gibt keine Ausgabeoptionen für das Format &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="811"/>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation>keine gültige Angabe von Wegpunkt-/Routen-/Trackfiltern</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="830"/>
        <source>No input file specified</source>
        <translation>keine Quelldatei angegeben</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="837"/>
        <source>No valid output specified</source>
        <translation>keine gültiges Ziel angegeben</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="842"/>
        <source>No output file specified</source>
        <translation>keine Zieldatei angegeben</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="858"/>
        <source>Process &quot;%1&quot; did not start</source>
        <translation>Prozess &quot;%1&quot; wurde nicht gestartet</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="872"/>
        <source>Process exited unsucessfully with code %1</source>
        <translation>Prozess endete mit code %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1007"/>
        <source>Translation successful</source>
        <translation>Konvertierung erfolgreich</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1018"/>
        <source>Error running gpsbabel: %1
</source>
        <translation>Fehler beim Aufruf von gpsbabel: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1132"/>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation>Sind Sie sicher, dass Sie alle Formatoptionen auf die Vorgaben stellen wollen?</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1155"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1198"/>
        <source>One or more data filters are active</source>
        <translation>Einer oder mehrere Datenfilter sind aktiviert</translation>
    </message>
    <message>
        <location filename="mainwindow.cc" line="1200"/>
        <source>No data filters are active</source>
        <translation>Keine Datenfilter sind aktiv</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation type="obsolete">Hauptfenster</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="14"/>
        <source>GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="21"/>
        <source>Input </source>
        <translation>Eingabe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="41"/>
        <source>If selected, input is from a file.</source>
        <translation>Wenn markiert, ist die Eingabe aus einer Datei.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="44"/>
        <location filename="mainwinui.ui" line="431"/>
        <location filename="mainwinui.ui" line="628"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="57"/>
        <source>If selected, input is from a device or GPS unit</source>
        <translation>Wenn markiert, ist die Eingabe aus einem Gerät oder einer GPS-Einheit</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="60"/>
        <location filename="mainwinui.ui" line="447"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="89"/>
        <location filename="mainwinui.ui" line="476"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="96"/>
        <source>Input data format</source>
        <translation>Eingabeformat</translation>
    </message>
    <message>
        <source>Character encoding of input</source>
        <translatorcomment>al.t: Codepage des Inputs - techspeak-like</translatorcomment>
        <translation type="obsolete">Zeichenkodierung der Quelldaten</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="120"/>
        <source>Browse for one or more input files. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Suchen nach Originaldateien</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="123"/>
        <source>File Name(s)</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="155"/>
        <location filename="mainwinui.ui" line="539"/>
        <source>Device Name:</source>
        <translation>Gerätename:</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="162"/>
        <source>Name of port to which input device is connected</source>
        <translation>Name der Schnittstelle, an der das Eingabegerät angeschlossen ist</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="193"/>
        <source>Options for the selected input format. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Optionen für das gewählte Eingabeformat</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="196"/>
        <location filename="mainwinui.ui" line="580"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="221"/>
        <source>Translation Options</source>
        <translation>Übersetzungsoptionen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="230"/>
        <location filename="mainwinui.ui" line="273"/>
        <location filename="mainwinui.ui" line="313"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="240"/>
        <source>If selected, translate waypoints.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>bei Auswahl: übersetzen von Wegpunkten</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="243"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="280"/>
        <source>If selected, translate routes.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>bei Auswahl: übersetzen von Routen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="283"/>
        <source>Routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="320"/>
        <source>If selected, translate tracks.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>bei Auswahl: übersetzen von Tracks</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="323"/>
        <source>Tracks</source>
        <translation>Tracks</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="359"/>
        <source>Data Filters between input and output</source>
        <translation>Datenfilter zwischen Ein- und Ausgabe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="362"/>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="395"/>
        <source>More translation options. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>weitere Übersetzungsoptionen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="398"/>
        <source>More Options</source>
        <translation>weitere Optionen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="408"/>
        <source>Output</source>
        <translation>Ausgabe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="428"/>
        <source>If selected, output is to a file. </source>
        <translation>Wenn markiert, geht die Ausgabe in eine Datei.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="444"/>
        <source>If selected, output is to a device or GPS unit</source>
        <translation>Wenn markiert, geht die Ausgabe in eine Gerät oder eine GPS-Einheit</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="483"/>
        <source>Output data format.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Ausgabeformat</translation>
    </message>
    <message>
        <source>Character encoding of output</source>
        <translatorcomment>alt.: Codepage der Ausgabe</translatorcomment>
        <translation type="obsolete">Zeichenkodierung der Ausgabe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="504"/>
        <source>Browse for an output file name. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Suchen nach Zieldatei-Namen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="507"/>
        <source>File Name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="546"/>
        <source>Name of port to which output device is connected</source>
        <translation>Name der Schnittstelle, an die das Ausgabegerät angeschlossen ist</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="577"/>
        <source>Options for the selected output format. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Optionen für das gewählte Ausgabeformat</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="601"/>
        <source>Output of GPSBabel translation process. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Ausgabe des GPSBabel Übersetzungsprozesses</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="635"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="651"/>
        <source>GPSBabel Help</source>
        <translation>GPSBabel Hilfe</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="656"/>
        <source>About GPSBabel</source>
        <translation>Über GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="661"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="666"/>
        <source>Preferences...</source>
        <translatorcomment>Via Google Translate</translatorcomment>
        <translation>Einstellungen ...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="671"/>
        <source>Check for Upgrade</source>
        <translation>Nach Upgrade suchen</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="676"/>
        <source>Visit Website...</source>
        <translation>Webseite besuchen ...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="681"/>
        <source>Make a Donation...</source>
        <translation>Spenden Sie...</translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <location filename="map.cc" line="76"/>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation>Datei &quot;gmapbase.html&quot; nicht gefunden. Prüfen Sie die Installation</translation>
    </message>
    <message>
        <location filename="map.cc" line="96"/>
        <source>Failed to load Google maps base page</source>
        <translation>Fehler beim Laden der Google maps Hauptseite</translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <location filename="miscfltui.ui" line="53"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="225"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Tracks</source>
        <translation>Tracks</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="60"/>
        <location filename="filterwidgets.cc" line="221"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="226"/>
        <source>Waypoints</source>
        <translation>Wegpunkte</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="46"/>
        <location filename="filterwidgets.cc" line="222"/>
        <location filename="filterwidgets.cc" line="223"/>
        <location filename="filterwidgets.cc" line="224"/>
        <location filename="filterwidgets.cc" line="225"/>
        <source>Routes</source>
        <translation>Routen</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>depends heavily on context - best guess</translatorcomment>
        <translation>Maske</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="27"/>
        <source>Misc. Filters</source>
        <translation>verschiedene Filter</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="34"/>
        <source>Nuke (Remove) Data Types</source>
        <translation>Bestimmte Datentypen löschen</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="72"/>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Konvertierung zwischen Routen, Wegpunkten und Tracks.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="75"/>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation>Dieser Filter kann verwendet werden, um GPS-Daten in andere Datentypen zu konvertieren.

Manche Dateiformate unterstuetzen nur eine Teilmenge, entweder Wegpunkte oder Tracks oder Routen. Der Transformationsfilter erlaubt die Konvertierung in andere Typen. Zum Beispiel kann er verwendet werden, um Wegpunkte (wie in einer CSV-Datei) in einen Track umzuwandeln oder umgekehrt.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="80"/>
        <source>Transform</source>
        <translation>Konvertieren</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="87"/>
        <source>Type of transformation. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Art der Konvertierung.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="94"/>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Vermeiden von redundanten Daten: löschen der Originaldaten.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="97"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="119"/>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Vertauschen von Länge und Breite, für fehlerhafte Datenformate.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="122"/>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation>Einfacher Filter, um die Koordinaten ( Länge und Breite ) aller Punkte zu vertauschen. Das kann hilfreich sein bei fehlerhaft geschriebenen Daten.Oder in Fällen wo die Verwendung eines xcsv-Formats sinnvoll erscheint aber Länge und Breite in umgekehrter Reihenfolge vorliegen.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="125"/>
        <source>Swap Coordinates</source>
        <translation>Koordinaten Vertauschen</translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <location filename="optionsdlg.cc" line="192"/>
        <location filename="optionsdlg.cc" line="203"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="preferences.ui" line="20"/>
        <source>GPSBabel Preferences</source>
        <translation>GPSBabel Einstellungen</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="30"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="45"/>
        <source>Check for newer version on start.</source>
        <translation>Beim Start auf neue Version überprüfen.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="52"/>
        <source>Anonymously report usage data.</source>
        <translation>Daten über die Benutzung anonym übertragen.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="59"/>
        <source>Ignore mismatch between command line and GUI version.</source>
        <translation>Konflikt zwischen Kommandozeilen- und GUI-Verson ignorieren.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="68"/>
        <source>Formats</source>
        <translation>Formate</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="76"/>
        <source>Enabled Formats</source>
        <translation>Aktivierte Formate</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="100"/>
        <source>Enable All</source>
        <translation>Alle aktivieren</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="107"/>
        <source>Disable All</source>
        <translatorcomment>Via GT</translatorcomment>
        <translation>Alle deaktivieren</translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <location filename="processwait.cc" line="43"/>
        <source>Process failed to start</source>
        <translation>Prozess konnte nicht gestartet werden</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="46"/>
        <source>Process crashed</source>
        <translation>Prozess-Crash</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="49"/>
        <source>Process timedout</source>
        <translation>Prozess-Timeout</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="52"/>
        <source>Error while trying to write to process</source>
        <translation>Fehler beim Schreiben zu einem Prozess</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="55"/>
        <source>Error while trying to read from process</source>
        <translation>Fehler beim Lesen von einem Prozess</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="59"/>
        <source>Unknown process error</source>
        <translation>unbekannter Prozess-Fehler</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="68"/>
        <source> ... Process GPSBabel</source>
        <translation>... Prozess GPSBabel</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="83"/>
        <source>Stop Process</source>
        <translation>Prozess beenden</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="155"/>
        <source>Process did not terminate successfully</source>
        <translation>Prozess endete mit Fehler</translation>
    </message>
    <message>
        <location filename="processwait.cc" line="174"/>
        <source>Process crashed whle running</source>
        <translation>Prozess-Crash bei Ausfuehrung</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="formatload.cc" line="155"/>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation>Fehler beim Verarbeiten der Formate vom laufenden Process &quot;gpsbabel-^3&quot; in  Zeile %1</translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <location filename="rttrkui.ui" line="14"/>
        <source>Form</source>
        <translatorcomment>translation depends heavily on context</translatorcomment>
        <translation>Maske</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="17"/>
        <source>Simplify routes and tracks by removing points</source>
        <translation>Vereinfachen von Routen und Tracks durch Löschen von Punkten</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="20"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Der &apos;Vereinfachungsfilter&apos; vereinfacht Routen oder Tracks und wird bei Dateitypen verwendet, die Begrenzungen bei der Zahl der Punkte haben. Er kann auch eingesetzt werden, um einfach nur die Komplexit&amp;aumlt einer Route zu verringern. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Der Filter entfernt solange Punkte aus allen Routen bis die Anzahl oder der entstehende Fehler in den gegebenen Grenzen ist. Dabei versucht er, den Character und die Form der originalen Route weitestgehend beizubehalten. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Die Qualit&amp;aumlt der Ergebnisse h&amp;aumlngt von der L&amp;aumlnge der Route ab und davon, wie dicht die Punkte beieinander liegen. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="40"/>
        <source>Routes &amp; Tracks</source>
        <translation>Routen &amp; Tracks</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="59"/>
        <source>Simplify</source>
        <translation>Vereinfachen</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="82"/>
        <source>Limit To</source>
        <translation>Begrenzen auf</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="89"/>
        <source>Maximum number points in track or route. </source>
        <translation>Maximale Zahl von Punkten im Ergebnis.</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="96"/>
        <source>Points</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="118"/>
        <source>Reverse tracks and routes</source>
        <translation>Umkehren von Tracks und Routen</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="125"/>
        <source>Reverse</source>
        <translation>Umdrehen</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="49"/>
        <source>Simplify route by removing points</source>
        <translation>Vereinfachen der Route durch Löschen von Punkten</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="52"/>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation>Der &apos;Vereinfachungsfilter&apos; vereinfacht Routen oder Tracks und wird bei Dateitypen verwendet, die Begrenzungen bei der Zahl der Punkte haben. Er kann auch eingesetzt werden, um einfach nur die Komplexität einer Route zu verringern.

Der Filter entfernt solange Punkte aus allen Routen bis die Anzahl oder der entstehende Fehler in den gegebenen Grenzen ist. Dabei versucht er, den Character und die Form der originalen Route weitestgehend beizubehalten.

Die Qualität der Ergebnisse hängt von der Länge der Route ab und davon, wie dicht die Punkte beieinander liegen.
</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="121"/>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translatorcomment>punctuation checked twice</translatorcomment>
        <translation>Die Umkehrung wird auf die einfachst-mögliche Art durchgeführt. Zeitangaben bleiben mit dem Original-Wegpunkt verbunden. Dadurch ergibt sich das interessante Detail, dass die Zeit in der resultierenden Route bzw. dem Track rückwärts läuft. Das führt dazu, daß insbesondere Magellan Mapsend wilde Dinge anstellt, wie z.B. daß jeder Wegpunkt auf einen anderen Tag gesetzt wird.
Außerdem führt es dazu, daß, wenn z.B. eine Autobahnausfahrt oder eine Einbahnstraße betroffen sind, ein blindes Vertrauen darauf zu einer ungemütlichen Fahrt führen dürfte.
Applikationen sind eben Zeitsensitiv</translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <location filename="trackui.ui" line="14"/>
        <source>Track Filter Options</source>
        <translation>Trackfilter-Optionen</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="17"/>
        <source>This filter performs various operations on track data. </source>
        <translation>Der Filter wendet verschiedene Funktionen auf Trackdaten an.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="35"/>
        <source>Track Filters</source>
        <translation>Trackfilter</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="42"/>
        <source>Basic title for track</source>
        <translation>Titel-Basis für den Track</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="45"/>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation>Titel-Basis für neue Tracks.
Diese Option definiert einen Titel für die Tracks, die vom Trackfilter generiert werden. Standard ist, daß sich der Titel des neuen Tracks aus dieser Basis und der Startzeit des Tracks zusammensetzt.
Wenn die Titelbasis ein &apos;%&apos;-Zeichen enthält, wird sie wie ein Format-String für doe POSIX-Funktion &apos;strftime&apos; interpretiert. Das erlaub die Anpassung der Tracktitel an die eigenen Bedürfnisse.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="50"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="57"/>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation>Der Titel des neuen Tracks setzt sich aus diesem Inhalt und der angehängten Startzeit des Tracks zusammen.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="64"/>
        <source>Correct track point timestamps by specified amount</source>
        <translation>Anpassen der Trackpunkt-Zeiten um den angegebenen Wert</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="67"/>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation>Anpassen der Trackpunkt-Zeiten um ein Delta.
Diese Option korrigiert die Uhrzeit aller Trackpunkte. Dies kann nützlich sein, wenn der Track um eine oder mehrere Stunden in der Zeit verschoben werden muss, z.B. wegen einer falschen Zeitzone.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="71"/>
        <source>Move</source>
        <translation>Verschieben</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="83"/>
        <location filename="trackui.ui" line="275"/>
        <source>days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="97"/>
        <source>hours</source>
        <translatorcomment>shortform variant seemed sensible</translatorcomment>
        <translation>Std.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="111"/>
        <location filename="trackui.ui" line="265"/>
        <source>mins</source>
        <translatorcomment>shortform variant seemed sensible</translatorcomment>
        <translation>Min.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="125"/>
        <source>secs</source>
        <translatorcomment>shortform variant seemed sensible</translatorcomment>
        <translation>Sek.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="140"/>
        <location filename="trackui.ui" line="155"/>
        <source>Use track pts. after this time. </source>
        <translation>Nur Trackpunkte nach diesem Zeitpunkt behalten.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="143"/>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation>Nur Trackpunkte nach diesem Zeitpunkt behalten.

Diese Option wird zusammen mit ihrem Gegenspieler verwendet, um Trackpunkte zu verwerfen, die sich ausserhalb eines bestimmten Zeitfensters befinden. Diese Option definiert den Anfang des Fensters.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="148"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="162"/>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation>Wenn angekreuzt, richtet sich die angegebene Zeit nach der Zeitzone dieses Computers.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="165"/>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation>Wenn angekreuzt, richtet sich die angegebene Zeit nach der Zeitzone dieses Computers. Wenn nicht, wird UTC angenommen.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="168"/>
        <source>Local Time</source>
        <translation>Lokale Zeit</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="181"/>
        <location filename="trackui.ui" line="196"/>
        <source>Use track pts before this time. </source>
        <translation>Nur Trackpunkte vor diesem Zeitpunkt behalten.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="184"/>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation>Nur Trackpunkte vor diesem Zeitpunkt behalten.

Diese Option wird zusammen mit ihrem Gegenstück verwendet, um alle Trackpunkte auβerhalb eines Zeitfensters zu verwerfen. Diese Option definiert das Ende des Fensters.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="189"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="203"/>
        <source>Pack all tracks into one. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Tracks zu einem Track verketten</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="206"/>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation>Alle Tracks zu einem verketten.

Diese Option sorgt dafür, daβ alle Tracks hintereinander zu einen gemeinsamen Track werden. Das funktioniert nicht, wenn die Zeitpunkte von Tracks überlappen. Falls das der Fall ist, kommt eher die &apos;Mischen&apos;-Funktion in Frage.

Diese Option eignet sich am besten dafuer, Tracks zu verbinden, die durch eine Fehlfunktion oder eine automatische &apos;über-Nacht-Auftrennung&apos; aufgeteilt wurden.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="213"/>
        <source>Pack</source>
        <translatorcomment>guesswork, depends on context</translatorcomment>
        <translation>Verketten</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="220"/>
        <source>Merge multiple tracks for the same way.</source>
        <translation>Tracks auf einem Weg mischen.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="223"/>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation>Tracks auf einem Weg mischen.

Diese Option übernimmt alle Punkte aus allen Tracks in einen einzigen Track und sortiert sie nach der Zeit. Punkte mit den gleichen Zeitdaten werden entfernt.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="228"/>
        <source>Merge</source>
        <translation>Mischen</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="235"/>
        <source>Split by Date</source>
        <oldsource>Split tracks. </oldsource>
        <translation>nach Datum teilen</translation>
    </message>
    <message>
        <source>Split by date or time interval 

The input track will be split into several tracks depending on date of track points. If there is more than one track, use the pack option before before using this. 

If the input has multiple tracks, pack them together before splitting them back apart per day.
</source>
        <translation type="obsolete">Aufspalten nach Datum oder Zeitintervall

Der Track wird aufgeteilt nach den Zeitdatum der Trackpunkte. Wenn mehrere Tracks verarbeitet werden sollen, müssen sie vorher zu einem kombiniert werden.

Mehrere Tracks, die sich ueber Tagesgrenzen verteilen, können so ebenfalls an Datumsgrenzen aufgesplittet werden.
</translation>
    </message>
    <message>
        <source>Split</source>
        <translation type="obsolete">Aufspalten</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="254"/>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation>Falls nicht Null, und wenn die Zeitdaten aufeinanderfolgender Trackpunkte gröβer sind als der angegebene Wert, wird der Track dort aufgesplittet. Bei Null wird der Track an den Datumsgrenzen aufgeteilt.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="270"/>
        <source>hrs</source>
        <translatorcomment>abbr point</translatorcomment>
        <translation>Std.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="285"/>
        <source>Split by Dist.</source>
        <translation>nach Entf. teilen</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="297"/>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation>Falls nicht Null, und wenn die Distanz aufeinanderfolgender Trackpunkte gröβer ist als der angegebene Wert, wird der Track dort aufgesplittet.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="308"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="313"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="318"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="323"/>
        <source>mi</source>
        <translation>meilen</translation>
    </message>
    <message>
        <source>Synthesize GPS Fixes. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation type="obsolete">GPS-Fixwerte generieren.</translation>
    </message>
    <message>
        <source>Synthesize GPS fixes (PPS, DGPS, 3D, 2D, NONE).

This option sets the GPS fix status for all trackpoints to the specified value. Valid values for this option are PPS, DGPS, 3D, 2D, or NONE.

This option is most useful when converting from a format that doesn&apos;t contain GPS fix status to one that requires it. </source>
        <translation type="obsolete">GPS-Fixwerte generieren.n (PPS, DGPS, 3D, 2D, KEINE).

Diese Option erzeugt GPS Fixwerte und setzt diese für alle Trackpunkte auf die angegebenen Werte. Gültige Werte sind: &apos;PPS&apos;, &apos;DGPS&apos;, &apos;3D&apos;, &apos;2D&apos;, oder &apos;KEINE&apos;.

Die Option wird eingesetzt, um ein Format, das keine Fixdaten enthält in eines zu konvertieren, das sie voraussetzt.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="341"/>
        <source>GPS Fixes</source>
        <translation>GPS Fixdaten</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="349"/>
        <source>none</source>
        <translation>keine</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="354"/>
        <source>pps</source>
        <translation>PPS</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="359"/>
        <source>dgps</source>
        <translation>DGPS</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="364"/>
        <source>3d</source>
        <translation>3d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="369"/>
        <source>2d</source>
        <translation>2d</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="407"/>
        <source>Synthesize course.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Kurswerte generieren</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="410"/>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation>Kurswerte generieren

Diese Option erzeugt oder errechnet einen Wert für den GPS-Kurs an jeden Trackpunkt. Das ist insbesondere dann nützlich, wenn ein Format konvertiert werden soll, das keine Kursdaten enthält - oder für Trackpunkte die vom Mittelwert-Filter generiert wurden. Der Kurs an einem Trackpunkt ist einfach die Richtung vom vorherigen Trackpunkt zum aktuellen. Dem ersten Trackpunkt in jedem Track wird automatisch ein Wert von null Grad zugewiesen.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="415"/>
        <source>Course</source>
        <translation>Kurs</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="392"/>
        <source>Synthesize speed. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Tempodaten generieren</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="242"/>
        <source>Split by Time</source>
        <translation>nach Zeit teilen</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="395"/>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translatorcomment>this time it _is_ a full sentence correct the original instead</translatorcomment>
        <translation>Tempodaten generieren

Diese Option generiert für jeden Trackpunkt einen Geschwindigkeitswert. Sie wird eingesetzt, wenn ein Format konvertiert werden soll, das diese Daten nicht enthält - oder bei Trackpunkten, die vom Mittelwert-Filter generiert wurden. Das Tempo an jedem Trackpunkt ist die mittlere Geschwindigkeit vom vorherigen (Weg durch Zeit). Dem ersten Trackpunkt in allen Tracks wird der Wert &apos;unbekannt&apos; zugewiesen.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="400"/>
        <source>Speed</source>
        <translation>Geschwindikgkeit</translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <location filename="upgrade.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <location filename="upgrade.cc" line="234"/>
        <location filename="upgrade.cc" line="238"/>
        <location filename="upgrade.cc" line="272"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="235"/>
        <source>Unexpected reply.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="239"/>
        <source>Download failed: %1.</source>
        <translation>Download fehlgeschlagen: %1.</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="273"/>
        <source>Download failed: %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="289"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="290"/>
        <source>Invalid return data at line %1: %2.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="331"/>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation>Eine neue Version von GPSBabel ist verfügbar.&lt;br /&gt;Die installierte Version ist %1 &lt;br /&gt;Die neueste Version ist %2</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="349"/>
        <source>Do you wish to download an upgrade?</source>
        <translation>Möchten Sie die Aktualisierung herunter laden?</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;b&gt;A new version of GPSBabel is available&lt;/b&gt;&lt;br&gt;Your version is %1 &lt;br&gt;The latest version is %2&lt;/center&gt;</source>
        <translation type="obsolete">&lt;center&gt;&lt;b&gt;Eine neue GPSBabel-Version ist verf&amp;uumlgbar&lt;/b&gt;&lt;br&gt;Die Version auf diesem Computer ist %1 &lt;br&gt;Die neueste Version ist %2&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="upgrade.cc" line="342"/>
        <source>Upgrade</source>
        <translation>Update</translation>
    </message>
</context>
<context>
    <name>VersionMismatch</name>
    <message>
        <location filename="version_mismatch.ui" line="32"/>
        <source>GPSBabel Version Mismatch</source>
        <translation>GPSBabel Versionskonflikt</translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="38"/>
        <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ein Versionskonflikt wurde gefunden.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="47"/>
        <source>GPSBabel command line version:</source>
        <translation>GPSBabel Kommandozeilenversion:</translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="81"/>
        <source>GPSBabel GUI version:</source>
        <translation>GPSBabel GUI Version:</translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="115"/>
        <source>Never show this message again.</source>
        <translation>Diese Meldung nicht mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <location filename="wayptsui.ui" line="14"/>
        <source>Form</source>
        <translation>Maske</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="29"/>
        <source>Waypoints Filters</source>
        <translation>Wegpunktfilter</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="36"/>
        <source>Remove duplicates</source>
        <translation>Duplikate beseitigen</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="39"/>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation>Der Duplikatfilter dient dazu, identische Punkte basierend auf ihrem Kurznamen (meist der Name des Punkt im GPS-Empfänger) und/oder ihrerPosition (bis auf eine Genauigkeit von 6 Nachkommastellen) zu beseitigen. Dieser Filter kennt zwei Varianten, nach denen sich die Art der Filterung richtet: &apos;Kurzname&apos; und &apos;Position&apos;. Mindestens eine dieser Varianten wird benötigt.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="42"/>
        <source>Duplicates</source>
        <translation>Duplikate</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="55"/>
        <source>Suppress duplicate waypoints based on name.</source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Unterdrücken gleichnamiger Wegpunkte</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="58"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translatorcomment>complicated... syntax ok, semantics questionable</translatorcomment>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Unterdrücken doppelter Wegpunkte anhand ihres Namens. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Diese Option ist die am häufigsten in Verbindung mit dem Duplikatfilter genutzte Variante. Sie steuert den Duplikatfilter so, dass dieser Wegpunkte entfernt, die einen gemeinsamen Kurznamen mit einem früher aufgetretenen Wegpunkt teilen. Die Option kann nützlich sein, wenn Duplikate entfernt werden sollen, die aus zwei unabhängigen Datenblöcken stammen, die aufbauend auf einem gemeinsamen Vorgaenger-Datenblock erzeugt wurden. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="66"/>
        <source>Short Names</source>
        <translation>Kurzname</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="73"/>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation>Unterdrücken von Wegpunkten mit gleichen Koordinaten</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="76"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translatorcomment>complicated, not sur if I understood enought to make a good translation style</translatorcomment>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Unterdrücken doppelter Wegpunkte anhand ihrer Koordinaten. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Diese Option steuert den Duplikatfilter so, dass er alle zusätzlichen Wegpunkte entfernt, die (auf sechs Dezimalstellen) die gleichen Koordinaten haben wie der vorhergehende. Die Option kann Verwendung finden beim Entfernen doppelter Wegpunkte, wenn ihre Namen voneinander abweichen. Sie kann ebenfalls mit der &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;Kurzname&lt;/span&gt;-Option kombiniert werden, die doppelte Wegpunkte entfernt, wenn diese zu unabhängigen Gruppen gehören, deren Namen aber übereinstimmen. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="84"/>
        <source>Locations</source>
        <translation>Positionen</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="91"/>
        <source>Remove points based on proximity</source>
        <translation>Beseitigen von Punkten auf Basis ihrer Nähe</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="94"/>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translation>Maximale Entfernung

Diese Option definiert den örtlichen mindestabstand zwischen den Punkten. Wenn zwei Punkte näher beieinander liegen als dieser Wert, wird einer davon entfernt.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="99"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="112"/>
        <source>Maximum positional distance.</source>
        <translation>Maximale Entfernung</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="120"/>
        <source>Feet</source>
        <translation>Fuβ</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="125"/>
        <source>Meters</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="133"/>
        <source>Include points only within radius</source>
        <translation>Übernahme von Punkten innerhalb eines Radius&apos;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="136"/>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation>Dieser Filter (de-)selektiert Wegpunkte aufgrund ihrer Entfernung von einem zentralen Punkt. Alle Wegpunkte, die weiter entfernt sind als die angegebene Distanz werden ausgefiltert.

Voreinstellung ist, dass die übrig gebliebenen Punkte nach ihrer Entfernung vom Zentrum sortiert werden. Sie erscheinen dann in dieser Reihenfolge in der Ergebnisdatei.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="141"/>
        <source>Radius</source>
        <translation>Radius</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="154"/>
        <source>Maximum distance from center. </source>
        <translatorcomment>no sentence</translatorcomment>
        <translation>Maximale Entfernung vom Zentrum</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="162"/>
        <source>Miles</source>
        <translation>Meilen</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="167"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="175"/>
        <source>Lat.</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="188"/>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation>Breitengrad des zentralen Punktes in Dezimalgraden. Südliche Breiten werden als negative Zahlen angegeben.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="195"/>
        <source>Long.</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="208"/>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation>Längengrad des zentralen Punktes in Dezimalgraden. Westliche Längen werden als negative Zahlen angegeben.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="215"/>
        <location filename="wayptsui.ui" line="218"/>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation>Dieser Filter sortiert Wegpunkte alphabetisch</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="221"/>
        <source>Sort</source>
        <translation>Sortieren</translation>
    </message>
</context>
</TS>
